@@ -5,6 +5,7 @@
 from r3sponse.classes.config import *
 from r3sponse.classes import utils
 from r3sponse.classes.utils import color, symbol
+from r3sponse.classes import exceptions
 from django.http import JsonResponse
 import json as pypi_json
 
@@ -411,10 +412,17 @@ class R3sponse(object):
 		def unpack(self, 
 			# the variable keys (#1 parameter).
 			keys=[],
+			# the safe defaults (must be in the same order).
+			defaults={},
 		):
 			list = []
 			for key in keys:
-				list.append(self[key])
+				value = 
+				try: value = self[key]
+				except KeyError: value = defaults[key]
+				if value == None:
+					raise exceptions.UnpackError(f"ResponseObject does not contain attribute [{key}].")
+				list.append(value)
 			return list
 		# clean default values.
 		def clean(self):
